@@ -25,22 +25,24 @@ as.data.frame.SDMXCompactData <- function(x, ...){
     & regexpr("http://www.w3.org", nsDefs.df$uri,
             "match.length", ignore.case = TRUE) == -1,]
   ns <- ns.df$uri
-  if(length(ns) > 1){
-    warning("More than one target dataset namespace found!")
-    ns <- ns[1L]
-  }
-  authorityNs <- nsDefs.df[nsDefs.df$uri == ns,]
-  if(nrow(authorityNs) == 0){
-    hasAuthorityNS <- FALSE
-  }else{
-    hasAuthorityNS <- TRUE
-  }
+  hasAuthorityNS <- FALSE
+  if(length(ns) > 0) hasAuthorityNS <- TRUE
   
   if(hasAuthorityNS){
-    seriesXML <- getNodeSet(xmlObj, "//ns:Series", c(ns = authorityNs$uri)) 
+    seriesXML <- unlist(
+      lapply(ns,
+             function(nsUri){
+                serieNs <- nsDefs.df[nsDefs.df$uri == nsUri,]
+                out <- NULL
+                s <- try(getNodeSet(xmlObj, "//ns:Series", c(ns = serieNs$uri)))
+                if(class(s) != "try-error") out <- s
+                return(out)
+             }))
+    
   }else{
     if(nrow(nsDefs.df) > 0){
-      seriesXML <- getNodeSet(xmlObj, "//ns:Series", c(ns = nsDefs.df[1,"uri"])) 
+      serieNs <- nsDefs.df[1,]
+      seriesXML <- getNodeSet(xmlObj, "//nt:Series", c(nt = serieNs$uri)) 
     }else{    
       stop("Unsupported CompactData parser for empty target XML namespace")
     }
@@ -49,26 +51,42 @@ as.data.frame.SDMXCompactData <- function(x, ...){
   #function to parse a Serie
   parseSerie <- function(x){
     
-    #obs values
+    #obs attributes (which may include observations)
     obsValueXML <- xmlChildren(x)
-    obsValue <- as.data.frame(
+    obsAttrs <- as.data.frame(
       do.call("rbind", lapply(obsValueXML, function(t){
         xmlAttrs(t)
       })),
       stringAsFactors = FALSE,
       row.names = 1:length(obsValueXML),
-      stringAsFactors = FALSE)
+      stringAsFactors = FALSE
+    )
+    
+    #obs children (in case we have)
+    obsValues <- try(xmlToDataFrame(obsValueXML, stringsAsFactors = FALSE), silent=TRUE)
+    if(class(obsValues) == "try-error"){
+      obsValues <- NULL
+    }else{
+      obsKeyNames <- names(lapply(obsValueXML, xmlChildren)[["Key"]])
+      obsValues[,obsKeyNames] <- obsValues[1,obsKeyNames]
+      obsValues <- obsValues[-1,]
+      invisible(lapply(obsKeyNames, function(t) obsValues[nchar(obsValues[,t])==0,t] <<- NA))
+    }
     
     #key values
     keydf <- as.data.frame(t(as.data.frame(xmlAttrs(x), stringAsFactors = FALSE)), stringAsFactors = FALSE)
-    if(nrow(obsValue) > 0){
-      keydf <- keydf[rep(row.names(keydf), nrow(obsValue)),]
-      if(class(keydf) == "data.frame") row.names(keydf) <- 1:nrow(obsValue)
+    if(nrow(obsAttrs) > 0){
+      keydf <- keydf[rep(row.names(keydf), nrow(obsAttrs)),]
+      if(class(keydf) == "data.frame") row.names(keydf) <- 1:nrow(obsAttrs)
     }
     
     #single Serie as DataFrame
-    if(nrow(obsValue) > 0){  
-      serie <- cbind(keydf, obsValue, row.names = 1:nrow(obsValue))
+    if(nrow(obsAttrs) > 0){
+      obsContent <- obsAttrs
+      if(!is.null(obsValues)){
+        obsContent <- cbind(obsAttrs, obsValues)
+      }
+      serie <- cbind(keydf, obsContent, row.names = 1:nrow(obsAttrs))
     }else{
       #manage absence data
       serie <- keydf
